==> rmumps_5.1.2-2.tar.gz: rmumps/src/lib/scotch_6.0.4/src/libscotch/dgraph_band_grow.h <==
/* Copyright 2012 IPB, Universite de Bordeaux, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : dgraph_band_grow.h                      **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : This file provides the prototypes of    **/
/**                the generic band graph growing          **/
/**                routines.                               **/
/**                                                        **/
/**   DATES      : # Version 6.0  : from : 26 sep 2012     **/
/**                                 to   : 26 sep 2012     **/
/**                                                        **/
/************************************************************/

/*
**  The defines.
*/

#define DGRAPHBANDGROWNAMECOLL      DGRAPHBANDGROWNAMECOLL2 (REPLACE (DGRAPHBANDGROWNAME))
#define DGRAPHBANDGROWNAMECOLL2(s)  GLUE (s,Coll)

#define DGRAPHBANDGROWNAMEPTOP      DGRAPHBANDGROWNAMEPTOP2 (REPLACE (DGRAPHBANDGROWNAME))
#define DGRAPHBANDGROWNAMEPTOP2(s)  GLUE (s,Ptop)

/*
** The function prototypes.
*/

int                         DGRAPHBANDGROWNAMECOLL (Dgraph * restrict const, const Gnum, Gnum * restrict const, const Gnum, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const);
int                         DGRAPHBANDGROWNAMEPTOP (Dgraph * restrict const, const Gnum, Gnum * restrict const, const Gnum, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const);

==> rmumps_5.2.1-28.tar.gz: rmumps/src/lib/scotch_6.0.9/src/libscotch/dgraph_band_grow.h <==
/* Copyright 2012 IPB, Universite de Bordeaux, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : dgraph_band_grow.h                      **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : This file provides the prototypes of    **/
/**                the generic band graph growing          **/
/**                routines.                               **/
/**                                                        **/
/**   DATES      : # Version 6.0  : from : 26 sep 2012     **/
/**                                 to   : 26 sep 2012     **/
/**                                                        **/
/************************************************************/

/*
**  The defines.
*/

#define DGRAPHBANDGROWNAMECOLL      REPLACE (DGRAPHBANDGROWNAMECOLL2 (REPLACE (DGRAPHBANDGROWNAME)))
#define DGRAPHBANDGROWNAMECOLL2(s)  GLUE (s,Coll)

#define DGRAPHBANDGROWNAMEPTOP      REPLACE (DGRAPHBANDGROWNAMEPTOP2 (REPLACE (DGRAPHBANDGROWNAME)))
#define DGRAPHBANDGROWNAMEPTOP2(s)  GLUE (s,Ptop)

/*
** The function prototypes.
*/

int                         DGRAPHBANDGROWNAMECOLL (Dgraph * restrict const, const Gnum, Gnum * restrict const, const Gnum, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const);
int                         DGRAPHBANDGROWNAMEPTOP (Dgraph * restrict const, const Gnum, Gnum * restrict const, const Gnum, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const);
